@@ -1,9 +1,14 @@
 <?php
+namespace LAM\ACCOUNT;
+use accountContainer;
+use DateTime;
+use LAM\TYPES\TypeManager;
+
 /*
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Tilo Lutz
-                2005 - 2019  Roland Gruber
+                2005 - 2021  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -62,7 +67,7 @@ if (isset($_GET['editKey'])) {
 	$sessionKey = htmlspecialchars($_GET['editKey']);
 }
 else {
-	$sessionKey = $sessionAccountPrefix . (new \DateTime(null, getTimeZone()))->getTimestamp() . getRandomNumber();
+	$sessionKey = $sessionAccountPrefix . (new DateTime(null, getTimeZone()))->getTimestamp() . getRandomNumber();
 }
 
 // cleanup account containers in session
@@ -82,31 +87,24 @@ foreach ($_SESSION as $key => $value) {
 	}
 }
 
-$typeManager = new LAM\TYPES\TypeManager();
+$typeManager = new TypeManager();
 //load account
-if (isset($_GET['DN'])) {
+
+if (!empty($_GET['DN'])) {
 	$type = $typeManager->getConfiguredType($_GET['type']);
-	$DN = str_replace("\\'", '', $_GET['DN']);
+	$dn = cleanDn($_GET['DN']);
 	if ($type->isHidden()) {
 		logNewMessage(LOG_ERR, 'User tried to access hidden account type: ' . $type->getId());
 		die();
 	}
-	if ($_GET['DN'] == $DN) {
-		if (substr($DN, 0, 1) === "'") {
-			$DN = substr($DN, 1);
-		}
-		if (substr($DN, -1, 1) === "'") {
-			$DN = substr($DN, 0, -1);
-		}
-	}
 	$suffix = strtolower($type->getSuffix());
-	$DNlower = strtolower($DN);
+	$DNlower = strtolower($dn);
 	if (strpos($DNlower, $suffix) !== (strlen($DNlower) - strlen($suffix))) {
 		logNewMessage(LOG_ERR, 'User tried to access entry of type ' . $type->getId() . ' outside suffix ' . $suffix);
 		die();
 	}
 	$_SESSION[$sessionKey] = new accountContainer($type, $sessionKey);
-	$result = $_SESSION[$sessionKey]->load_account($DN);
+	$result = $_SESSION[$sessionKey]->load_account($dn);
 	if (sizeof($result) > 0) {
 		include __DIR__ . '/../../lib/adminHeader.inc';
 		foreach ($result as $message) {
@@ -129,9 +127,36 @@ elseif (empty($_POST)) {
 	}
 	$_SESSION[$sessionKey] = new accountContainer($type, $sessionKey);
 	$_SESSION[$sessionKey]->new_account();
+	if (!empty($_GET['copyDn'])) {
+		$copyDn = cleanDn($_GET['copyDn']);
+		$copyDnLower = strtolower($copyDn);
+		$suffix = strtolower($type->getSuffix());
+		if (strpos($copyDnLower, $suffix) !== (strlen($copyDnLower) - strlen($suffix))) {
+			logNewMessage(LOG_ERR, 'User tried to access entry of type ' . $type->getId() . ' outside suffix ' . $suffix);
+			die();
+		}
+		$_SESSION[$sessionKey]->copyFromExistingAccount($copyDn);
+	}
 }
 
 // show account page
 $_SESSION[$sessionKey]->continue_main();
 
-?>
+/**
+ * Cleans the given DN from GET.
+ *
+ * @param string $dn DN
+ * @return string cleaned DN
+ */
+function cleanDn(string $dn) : string {
+	$cleanDn = str_replace("\\'", '', $dn);
+	if ($dn == $cleanDn) {
+		if (substr($cleanDn, 0, 1) === "'") {
+			$cleanDn = substr($cleanDn, 1);
+		}
+		if (substr($cleanDn, -1, 1) === "'") {
+			$cleanDn = substr($cleanDn, 0, -1);
+		}
+	}
+	return $cleanDn;
+}
