@@ -14,7 +14,7 @@ use \htmlResponsiveRow;
 use \htmlResponsiveInputField;
 /*
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2004 - 2018  Roland Gruber
+  Copyright (C) 2004 - 2021  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -407,7 +407,11 @@ function checkInput() {
 			$typeSettings[$key] = (isset($_POST[$key]) && ($_POST[$key] == 'on'));
 		}
 		// check dynamic type settings
-		$typeObj = $typeManager->getConfiguredType($accountType)->getBaseType();
+		$configuredType = $typeManager->getConfiguredType($accountType);
+		if ($configuredType === null) {
+			continue;
+		}
+		$typeObj = $configuredType->getBaseType();
 		$typeMessages = $typeObj->check_configOptions($typeConfigOptions);
 		if (!empty($typeMessages)) {
 			$errors = array_merge($errors, $typeMessages);
