@@ -24,6 +24,7 @@ use \htmlResponsiveInputCheckbox;
 use \htmlResponsiveInputField;
 use \htmlDiv;
 use \htmlHiddenInput;
+use LAMException;
 use PDO;
 
 /*
@@ -93,7 +94,7 @@ $errors = array();
 $messages = array();
 // check if submit button was pressed
 if (isset($_POST['submitFormData'])) {
-    if (extension_loaded('PDO') && isDeveloperVersion(LAMVersion())) {
+    if (extension_loaded('PDO')) {
 	    // set database
 	    $cfg->configDatabaseType = $_POST['configDatabaseType'];
 	    $cfg->configDatabaseServer = $_POST['configDatabaseServer'];
@@ -158,7 +159,7 @@ if (isset($_POST['submitFormData'])) {
 			}
 			// check each line
 			$ipRegex = '/^[0-9a-f\\.:\\*]+$/i';
-			if (!preg_match($ipRegex, $allowedHostsList[$i]) || (strlen($allowedHostsList[$i]) > 15)) {
+			if (!preg_match($ipRegex, $allowedHostsList[$i]) || (strlen($allowedHostsList[$i]) > 45)) {
 				$errors[] = sprintf(_("The IP address %s is invalid!"), htmlspecialchars(str_replace('%', '%%', $allowedHostsList[$i])));
 			}
 		}
@@ -283,6 +284,7 @@ if (isset($_POST['submitFormData'])) {
 	if (isLAMProVersion()) {
 		$cfg->mailUser = $_POST['mailUser'];
 		$cfg->mailPassword = $_POST['mailPassword'];
+		$cfg->mailEncryption = $_POST['mailEncryption'];
 		$cfg->mailServer = $_POST['mailServer'];
 		if (!empty($cfg->mailServer) && !get_preg($cfg->mailServer, 'hostAndPort')) {
             $errors[] = _('Please enter the mail server with host name and port.');
@@ -354,7 +356,7 @@ printHeaderContents(_("Edit general settings"), '../..');
 	}
 
 	// database
-	if (extension_loaded('PDO') && isDeveloperVersion(LAMVersion())) {
+	if (extension_loaded('PDO')) {
 		$row->add(new htmlSubTitle(_('Configuration storage')), 12);
 		$storageProviders = array(
 			_('Local file system') => LAMCfgMain::DATABASE_FILE_SYSTEM
@@ -496,14 +498,17 @@ printHeaderContents(_("Edit general settings"), '../..');
 
 	// password policy
 	$row->add(new htmlSubTitle(_("Password policy")), 12);
-	$options20 = array(0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20);
+	$optionsPwdLength = array();
+	for ($i = 0; $i <= 50; $i++) {
+		$optionsPwdLength[] = $i;
+	}
 	$options4 = array(0, 1, 2, 3, 4);
-	$row->add(new htmlResponsiveSelect('passwordMinLength', $options20, array($cfg->passwordMinLength), _('Minimum password length'), '242'), 12);
+	$row->add(new htmlResponsiveSelect('passwordMinLength', $optionsPwdLength, array($cfg->passwordMinLength), _('Minimum password length'), '242'), 12);
 	$row->addVerticalSpacer('1rem');
-	$row->add(new htmlResponsiveSelect('passwordMinLower', $options20, array($cfg->passwordMinLower), _('Minimum lowercase characters'), '242'), 12);
-	$row->add(new htmlResponsiveSelect('passwordMinUpper', $options20, array($cfg->passwordMinUpper), _('Minimum uppercase characters'), '242'), 12);
-	$row->add(new htmlResponsiveSelect('passwordMinNumeric', $options20, array($cfg->passwordMinNumeric), _('Minimum numeric characters'), '242'), 12);
-	$row->add(new htmlResponsiveSelect('passwordMinSymbol', $options20, array($cfg->passwordMinSymbol), _('Minimum symbolic characters'), '242'), 12);
+	$row->add(new htmlResponsiveSelect('passwordMinLower', $optionsPwdLength, array($cfg->passwordMinLower), _('Minimum lowercase characters'), '242'), 12);
+	$row->add(new htmlResponsiveSelect('passwordMinUpper', $optionsPwdLength, array($cfg->passwordMinUpper), _('Minimum uppercase characters'), '242'), 12);
+	$row->add(new htmlResponsiveSelect('passwordMinNumeric', $optionsPwdLength, array($cfg->passwordMinNumeric), _('Minimum numeric characters'), '242'), 12);
+	$row->add(new htmlResponsiveSelect('passwordMinSymbol', $optionsPwdLength, array($cfg->passwordMinSymbol), _('Minimum symbolic characters'), '242'), 12);
 	$row->add(new htmlResponsiveSelect('passwordMinClasses', $options4, array($cfg->passwordMinClasses), _('Minimum character classes'), '242'), 12);
 	$row->addVerticalSpacer('1rem');
 	$rulesCountOptions = array(_('all') => '-1', '3' => '3', '4' => '4');
@@ -580,6 +585,15 @@ printHeaderContents(_("Edit general settings"), '../..');
 		$mailPassword = new htmlResponsiveInputField(_("Password"), 'mailPassword', $cfg->mailPassword, '255');
 		$mailPassword->setIsPassword(true);
 		$row->add($mailPassword, 12);
+		$mailEncryptionOptions = array(
+	        'TLS' => LAMCfgMain::SMTP_TLS,
+			'SSL' => LAMCfgMain::SMTP_SSL,
+			_('None') => LAMCfgMain::SMTP_NONE,
+        );
+		$selectedMailEncryption = empty($cfg->mailEncryption) ? LAMCfgMain::SMTP_TLS : $cfg->mailEncryption;
+		$mailEncryptionSelect = new htmlResponsiveSelect('mailEncryption', $mailEncryptionOptions, array($selectedMailEncryption), _('Encryption protocol'), '256');
+		$mailEncryptionSelect->setHasDescriptiveElements(true);
+		$row->add($mailEncryptionSelect, 12);
 	}
 	$row->addVerticalSpacer('3rem');
 
@@ -588,20 +602,26 @@ printHeaderContents(_("Edit general settings"), '../..');
 		&& in_array('sqlite', \PDO::getAvailableDrivers())) {
 		include_once __DIR__ . '/../../lib/webauthn.inc';
 		$webAuthnManager = new WebauthnManager();
-		$database = $webAuthnManager->getDatabase();
-		if ($database->hasRegisteredCredentials()) {
-			$row->add(new htmlSubTitle(_('WebAuthn devices')), 12);
-			$webauthnSearchField = new htmlResponsiveInputField(_('User DN'), 'webauthn_searchTerm', null, '252');
-			$row->add($webauthnSearchField, 12);
-			$row->addVerticalSpacer('0.5rem');
-			$row->add(new htmlButton('webauthn_search', _('Search')), 12, 12, 12, 'text-center');
-			$resultDiv = new htmlDiv('webauthn_results', new htmlOutputText(''), array('lam-webauthn-results'));
-			addSecurityTokenToSession(false);
-			$resultDiv->addDataAttribute('sec_token_value', getSecurityTokenValue());
-			$row->add($resultDiv, 12);
-			$confirmationDiv = new htmlDiv('webauthnDeleteConfirm', new htmlOutputText(_('Do you really want to remove this device?')), array('hidden'));
-			$row->add($confirmationDiv, 12);
+		try {
+			$database = $webAuthnManager->getDatabase();
+			if ($database->hasRegisteredCredentials()) {
+				$row->add(new htmlSubTitle(_('WebAuthn devices')), 12);
+				$webauthnSearchField = new htmlResponsiveInputField(_('User DN'), 'webauthn_searchTerm', null, '252');
+				$row->add($webauthnSearchField, 12);
+				$row->addVerticalSpacer('0.5rem');
+				$row->add(new htmlButton('webauthn_search', _('Search')), 12, 12, 12, 'text-center');
+				$resultDiv = new htmlDiv('webauthn_results', new htmlOutputText(''), array('lam-webauthn-results'));
+				addSecurityTokenToSession(false);
+				$resultDiv->addDataAttribute('sec_token_value', getSecurityTokenValue());
+				$row->add($resultDiv, 12);
+				$confirmationDiv = new htmlDiv('webauthnDeleteConfirm', new htmlOutputText(_('Do you really want to remove this device?')), array('hidden'));
+				$row->add($confirmationDiv, 12);
+			}
 		}
+		catch (LAMException $e) {
+		    logNewMessage(LOG_ERR, 'Webauthn error: ' . $e->getTitle() . ' ' . $e->getMessage());
+		    $row->add(new htmlStatusMessage('ERROR', $e->getTitle()), 12);
+        }
 	}
 
 	// change master password
