@@ -2,7 +2,7 @@
 /*
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2018  Roland Gruber
+  Copyright (C) 2003 - 2019  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -100,7 +100,9 @@ if (isset($_POST['add_suff']) || isset($_POST['cancel'])) {
 						$dnPartsCount = sizeof($dnParts);
 						for ($k = 0; $k < $dnPartsCount; $k++) {
 							$part = explode("=", $dnParts[$k]);
-							if ($part[0] == "ou") $subsuffs[] = implode(",", array_slice($dnParts, $k));
+							if ($part[0] == "ou") {
+								$subsuffs[] = implode(",", array_slice($dnParts, $k));
+							}
 							else {
 								$subsuffs[] = implode(",", array_slice($dnParts, $k));
 								break;
@@ -165,7 +167,7 @@ if (isset($_POST['add_suff']) || isset($_POST['cancel'])) {
 		else {
 			// print success message
 			StatusMessage("INFO", "", _("All changes were successful."));
-			include 'main_footer.php';
+			include '../lib/adminFooter.inc';
 		}
 	}
 	else {
