@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -31,40 +31,40 @@ CKEDITOR.lang[ 'sq' ] = {
 		url: 'URL',
 		protocol: 'Protokolli',
 		upload: 'Ngarko',
-		uploadSubmit: 'Dërgo në server',
-		image: 'Imazh',
+		uploadSubmit: 'E dërgo në server',
+		image: 'Foto',
 		flash: 'Objekt flash',
-		form: 'Formular',
-		checkbox: 'Checkbox',
-		radio: 'Buton radio',
-		textField: 'Fushë tekst',
-		textarea: 'Hapësirë tekst',
+		form: 'Formulari',
+		checkbox: 'Kuti përzgjedhjeje',
+		radio: 'Pullë përzgjedhjeje',
+		textField: 'Fushë teksti',
+		textarea: 'Hapësirë teksti',
 		hiddenField: 'Fushë e fshehur',
-		button: 'Buton',
-		select: 'Menu zgjedhjeje',
-		imageButton: 'Buton imazhi',
-		notSet: '<e pazgjedhur>',
+		button: 'Pullë',
+		select: 'Fusha e përzgjedhjeve',
+		imageButton: 'Pullë fotografie',
+		notSet: '<not set>',
 		id: 'Id',
-		name: 'Emër',
-		langDir: 'Kod gjuhe',
+		name: 'Emri',
+		langDir: 'Drejtim gjuhe',
 		langDirLtr: 'Nga e majta në të djathtë (LTR)',
 		langDirRtl: 'Nga e djathta në të majtë (RTL)',
-		langCode: 'Kod gjuhe',
-		longDescr: 'Përshkrim i hollësishëm',
-		cssClass: 'Klasa stili CSS',
-		advisoryTitle: 'Titull',
-		cssStyle: 'Stil',
-		ok: 'OK',
+		langCode: 'Kodi i Gjuhës',
+		longDescr: 'URL e përshkrimit të hollësishëm',
+		cssClass: 'CSS Klasat',
+		advisoryTitle: 'Titulli Konsultativ',
+		cssStyle: 'Stili',
+		ok: 'Mirë',
 		cancel: 'Anulo',
 		close: 'Mbyll',
-		preview: 'Parashiko',
-		resize: 'Ripërmaso',
+		preview: 'Parashih',
+		resize: 'Ndrysho madhësinë',
 		generalTab: 'Të përgjithshme',
 		advancedTab: 'Të përparuara',
-		validateNumberFailed: 'Vlera e futur nuk është një numër',
-		confirmNewPage: 'Çdo ndryshim që nuk është ruajtur do humbasë. Je i sigurtë që dëshiron të krijosh një faqe të re?',
-		confirmCancel: 'Disa opsione kanë ndryshuar. Je i sigurtë që dëshiron ta mbyllësh dritaren?',
-		options: 'Opsione',
+		validateNumberFailed: 'Kjo vlerë nuk është numër.',
+		confirmNewPage: 'Çdo ndryshim që nuk është ruajtur do humbasë. Je i sigurt që dëshiron të hapsh faqe të re?',
+		confirmCancel: 'Ke ndryshuar ca mundësi. Je i sigurt që dëshiron ta mbyllësh dritaren?',
+		options: 'Mundësitë',
 		target: 'Objektivi',
 		targetNew: 'Dritare e re (_blank)',
 		targetTop: 'Dritare në plan të parë (_top)',
@@ -72,18 +72,18 @@ CKEDITOR.lang[ 'sq' ] = {
 		targetParent: 'Dritarja prind (_parent)',
 		langDirLTR: 'Nga e majta në të djathë (LTR)',
 		langDirRTL: 'Nga e djathta në të majtë (RTL)',
-		styles: 'Stil',
-		cssClasses: 'Klasa Stili CSS',
-		width: 'Gjerësi',
-		height: 'Lartësi',
-		align: 'Rreshtim',
+		styles: 'Stili',
+		cssClasses: 'CSS Klasat',
+		width: 'Gjerësia',
+		height: 'Lartësia',
+		align: 'Rreshtimi',
 		left: 'Majtas',
 		right: 'Djathtas',
-		center: 'Qendër',
+		center: 'Në mes',
 		justify: 'Zgjero',
 		alignLeft: 'Rreshto majtas',
 		alignRight: 'Rreshto Djathtas',
-		alignCenter: 'Align Center', // MISSING
+		alignCenter: 'Rreshto në mes',
 		alignTop: 'Lart',
 		alignMiddle: 'Në mes',
 		alignBottom: 'Poshtë',
@@ -94,8 +94,8 @@ CKEDITOR.lang[ 'sq' ] = {
 		invalidLength: 'Vlera e përcaktuar për fushën "%1" duhet të jetë pozitive me ose pa njësi matëse me vlerë (%2).',
 		invalidCssLength: 'Vlera e fushës "%1" duhet të jetë një numër pozitiv me apo pa njësi matëse të vlefshme CSS (px, %, in, cm, mm, em, ex, pt ose pc).',
 		invalidHtmlLength: 'Vlera e fushës "%1" duhet të jetë një numër pozitiv me apo pa njësi matëse të vlefshme HTML (px ose %)',
-		invalidInlineStyle: 'Stili inline duhet të jetë një apo disa vlera të formatit "emër: vlerë", ndarë nga pikëpresje.',
-		cssLengthTooltip: 'Fut një numër për vlerën në pixel apo një numër me një njësi të vlefshme CSS (px, %, in, cm, mm, ex, pt, ose pc).',
+		invalidInlineStyle: 'Vlera e përcaktuar për stilin e vijëzuar duhet përmbajtur një ose më shumë vlera me format "emër : vlerë", të ndara me pikëpresje.',
+		cssLengthTooltip: 'Shto një numër për vlerën në piksel ose një numër me njësi të vlefshme CSS (px, %, in, cm, mm, em, ex, pt, or pc).',
 
 		// Put the voice-only part of the label in the span.
 		unavailable: '%1<span class="cke_accessibility">, i padisponueshëm</span>',
@@ -110,7 +110,7 @@ CKEDITOR.lang[ 'sq' ] = {
 			32: 'Hapësirë',
 			35: 'End',
 			36: 'Home',
-			46: 'Grise',
+			46: 'Delete',
 			112: 'F1',
 			113: 'F2',
 			114: 'F3',
@@ -135,7 +135,7 @@ CKEDITOR.lang[ 'sq' ] = {
 			133: 'F22',
 			134: 'F23',
 			135: 'F24',
-			224: 'Urdhëri'
+			224: 'Urdhri'
 		},
 
 		// Prepended to ARIA labels with shortcuts.
