@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'clipboard', 'nb', {
@@ -10,6 +10,5 @@ CKEDITOR.plugins.setLang( 'clipboard', 'nb', {
 	paste: 'Lim inn',
 	pasteNotification: 'Trykk %1 for å lime inn. Nettleseren din støtter ikke å lime inn med knappen i verktøylinjen eller høyreklikkmenyen.',
 	pasteArea: 'Innlimingsområde',
-	pasteMsg: 'Lim inn innholdet i området nedenfor og klikk OK.',
-	title: 'Lim inn'
+	pasteMsg: 'Lim inn innholdet i området nedenfor og klikk OK.'
 } );
