@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'clipboard', 'sv', {
@@ -10,6 +10,5 @@ CKEDITOR.plugins.setLang( 'clipboard', 'sv', {
 	paste: 'Klistra in',
 	pasteNotification: 'Tryck på %1 för att klistra in. Din webbläsare stödjer inte inklistring via verktygsfältet eller snabbmenyn.',
 	pasteArea: 'Inklistringsområde',
-	pasteMsg: 'Klistra in ditt innehåll i området nedan och tryck på OK.',
-	title: 'Klistra in'
+	pasteMsg: 'Klistra in ditt innehåll i området nedan och tryck på OK.'
 } );
