@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'colordialog', 'bg', {
@@ -7,5 +7,5 @@ CKEDITOR.plugins.setLang( 'colordialog', 'bg', {
 	highlight: 'Осветяване',
 	options: 'Цветови опции',
 	selected: 'Изберете цвят',
-	title: 'Изберете цвят'
+	title: 'Избор на цвят'
 } );
