@@ -1,5 +1,5 @@
-﻿/**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/**
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -67,6 +67,9 @@ CKEDITOR.plugins.add( 'format', {
 				var style = styles[ value ],
 					elementPath = editor.elementPath();
 
+				// (#3649)
+				editor.fire( 'stylesRemove', { type: CKEDITOR.STYLE_BLOCK } );
+
 				// Always apply style, do not allow to toggle it by clicking on corresponding list item (#584).
 				if ( !style.checkActive( elementPath, editor ) ) {
 					editor.applyStyle( style );
@@ -141,8 +144,8 @@ CKEDITOR.plugins.add( 'format', {
  * setting named `'format_(tagName)'`. For example, the `'p'` entry has its
  * definition taken from [config.format_p](#!/api/CKEDITOR.config-cfg-format_p).
  *
- * Read more in the [documentation](#!/guide/dev_format)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/format.html).
+ * Read more in the {@glink features/format documentation}
+ * and see the {@glink examples/format example}.
  *
  *		config.format_tags = 'p;h2;h3;pre';
  *
@@ -154,8 +157,8 @@ CKEDITOR.config.format_tags = 'p;h1;h2;h3;h4;h5;h6;pre;address;div';
 /**
  * The style definition to be used to apply the `Normal` format.
  *
- * Read more in the [documentation](#!/guide/dev_format)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/format.html).
+ * Read more in the {@glink features/format documentation}
+ * and see the {@glink examples/format example}.
  *
  *		config.format_p = { element: 'p', attributes: { 'class': 'normalPara' } };
  *
@@ -167,8 +170,8 @@ CKEDITOR.config.format_p = { element: 'p' };
 /**
  * The style definition to be used to apply the `Normal (DIV)` format.
  *
- * Read more in the [documentation](#!/guide/dev_format)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/format.html).
+ * Read more in the {@glink features/format documentation}
+ * and see the {@glink examples/format example}.
  *
  *		config.format_div = { element: 'div', attributes: { 'class': 'normalDiv' } };
  *
@@ -180,8 +183,8 @@ CKEDITOR.config.format_div = { element: 'div' };
 /**
  * The style definition to be used to apply the `Formatted` format.
  *
- * Read more in the [documentation](#!/guide/dev_format)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/format.html).
+ * Read more in the {@glink features/format documentation}
+ * and see the {@glink examples/format example}.
  *
  *		config.format_pre = { element: 'pre', attributes: { 'class': 'code' } };
  *
@@ -193,8 +196,8 @@ CKEDITOR.config.format_pre = { element: 'pre' };
 /**
  * The style definition to be used to apply the `Address` format.
  *
- * Read more in the [documentation](#!/guide/dev_format)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/format.html).
+ * Read more in the {@glink features/format documentation}
+ * and see the {@glink examples/format example}.
  *
  *		config.format_address = { element: 'address', attributes: { 'class': 'styledAddress' } };
  *
@@ -206,8 +209,8 @@ CKEDITOR.config.format_address = { element: 'address' };
 /**
  * The style definition to be used to apply the `Heading 1` format.
  *
- * Read more in the [documentation](#!/guide/dev_format)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/format.html).
+ * Read more in the {@glink features/format documentation}
+ * and see the {@glink examples/format example}.
  *
  *		config.format_h1 = { element: 'h1', attributes: { 'class': 'contentTitle1' } };
  *
@@ -219,8 +222,8 @@ CKEDITOR.config.format_h1 = { element: 'h1' };
 /**
  * The style definition to be used to apply the `Heading 2` format.
  *
- * Read more in the [documentation](#!/guide/dev_format)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/format.html).
+ * Read more in the {@glink features/format documentation}
+ * and see the {@glink examples/format example}.
  *
  *		config.format_h2 = { element: 'h2', attributes: { 'class': 'contentTitle2' } };
  *
@@ -232,8 +235,8 @@ CKEDITOR.config.format_h2 = { element: 'h2' };
 /**
  * The style definition to be used to apply the `Heading 3` format.
  *
- * Read more in the [documentation](#!/guide/dev_format)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/format.html).
+ * Read more in the {@glink features/format documentation}
+ * and see the {@glink examples/format example}.
  *
  *		config.format_h3 = { element: 'h3', attributes: { 'class': 'contentTitle3' } };
  *
@@ -245,8 +248,8 @@ CKEDITOR.config.format_h3 = { element: 'h3' };
 /**
  * The style definition to be used to apply the `Heading 4` format.
  *
- * Read more in the [documentation](#!/guide/dev_format)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/format.html).
+ * Read more in the {@glink features/format documentation}
+ * and see the {@glink examples/format example}.
  *
  *		config.format_h4 = { element: 'h4', attributes: { 'class': 'contentTitle4' } };
  *
@@ -258,8 +261,8 @@ CKEDITOR.config.format_h4 = { element: 'h4' };
 /**
  * The style definition to be used to apply the `Heading 5` format.
  *
- * Read more in the [documentation](#!/guide/dev_format)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/format.html).
+ * Read more in the {@glink features/format documentation}
+ * and see the {@glink examples/format example}.
  *
  *		config.format_h5 = { element: 'h5', attributes: { 'class': 'contentTitle5' } };
  *
@@ -271,8 +274,8 @@ CKEDITOR.config.format_h5 = { element: 'h5' };
 /**
  * The style definition to be used to apply the `Heading 6` format.
  *
- * Read more in the [documentation](#!/guide/dev_format)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/format.html).
+ * Read more in the {@glink features/format documentation}
+ * and see the {@glink examples/format example}.
  *
  *		config.format_h6 = { element: 'h6', attributes: { 'class': 'contentTitle6' } };
  *
