@@ -1,7 +1,7 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'horizontalrule', 'sq', {
-	toolbar: 'Vendos Vijë Horizontale'
+	toolbar: 'Shto Vijë Horizontale'
 } );
