@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'iframe', 'ar', {
@@ -7,5 +7,6 @@ CKEDITOR.plugins.setLang( 'iframe', 'ar', {
 	noUrl: 'فضلا أكتب رابط الـ iframe',
 	scrolling: 'تفعيل أشرطة الإنتقال',
 	title: 'خصائص iframe',
-	toolbar: 'iframe'
+	toolbar: 'iframe',
+	tabindex: 'Remove from tabindex' // MISSING
 } );
