@@ -1,11 +1,12 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'iframe', 'bg', {
 	border: 'Показва рамка на карето',
 	noUrl: 'Моля въведете URL за iFrame',
-	scrolling: 'Вкл. скролбаровете',
+	scrolling: 'Активира прелистване',
 	title: 'IFrame настройки',
-	toolbar: 'IFrame'
+	toolbar: 'IFrame',
+	tabindex: 'Remove from tabindex' // MISSING
 } );
