@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'image', 'lv', {
@@ -10,7 +10,7 @@ CKEDITOR.plugins.setLang( 'image', 'lv', {
 	hSpace: 'Horizontālā telpa',
 	img2Button: 'Vai vēlaties pārveidot izvēlēto attēlu uz attēla pogas?',
 	infoTab: 'Informācija par attēlu',
-	linkTab: 'Hipersaite',
+	linkTab: 'Saite',
 	lockRatio: 'Nemainīga Augstuma/Platuma attiecība',
 	menu: 'Attēla īpašības',
 	resetSize: 'Atjaunot sākotnējo izmēru',
