@@ -1,5 +1,5 @@
 ﻿/**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -17,13 +17,14 @@
 		icons: 'image', // %REMOVE_LINE_CORE%
 		hidpi: true, // %REMOVE_LINE_CORE%
 		init: function( editor ) {
-			// Abort when Image2 is to be loaded since both plugins
-			// share the same button, command, etc. names (https://dev.ckeditor.com/ticket/11222).
-			if ( editor.plugins.image2 )
-				return;
-
 			var pluginName = 'image';
 
+			// Abort when Easyimage or Image2 are to be loaded since this plugins
+			// share the same functionality (#1791).
+			if ( editor.plugins.detectConflict( pluginName, [ 'easyimage', 'image2' ] ) ) {
+				return;
+			}
+
 			// Register the dialog.
 			CKEDITOR.dialog.add( pluginName, this.path + 'dialogs/image.js' );
 
@@ -158,7 +159,7 @@
  *
  *		config.image_prefillDimensions = false;
  *
- * @since 4.5
+ * @since 4.5.0
  * @cfg {Boolean} [image_prefillDimensions=true]
  * @member CKEDITOR.config
  */
