@@ -1,5 +1,5 @@
 ﻿/**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -195,10 +195,10 @@
 
 			// #455
 			// 1. Check if we are directly in editbale. Justification should be always allowed, and not highlighted.
-			//    Checking path.elements.length is required to filter out situation `body > ul` where ul is selected and path.blockLimit returns editable.
+			//    Checking situation `body > ul` where ul is selected and path.blockLimit returns editable.
 			// 2. Check if current element can have applied specific class.
 			// 3. Check if current element can have applied text-align style.
-			if (  isEditable && path.elements.length === 1 ) {
+			if ( isEditable && !CKEDITOR.dtd.$list[ path.lastElement.getName() ] ) {
 				this.setState( CKEDITOR.TRISTATE_OFF );
 			} else if ( !isEditable && isStylable ) {
 				// 2 & 3 in one condition.
