@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'link', 'hr', {
@@ -35,7 +35,9 @@ CKEDITOR.plugins.setLang( 'link', 'hr', {
 	noAnchors: '(Nema dostupnih sidra)',
 	noEmail: 'Molimo upišite e-mail adresu',
 	noUrl: 'Molimo upišite URL link',
+	noTel: 'Please type the phone number', // MISSING
 	other: '<drugi>',
+	phoneNumber: 'Phone number', // MISSING
 	popupDependent: 'Ovisno (Netscape)',
 	popupFeatures: 'Mogućnosti popup prozora',
 	popupFullScreen: 'Cijeli ekran (IE)',
@@ -60,6 +62,7 @@ CKEDITOR.plugins.setLang( 'link', 'hr', {
 	toAnchor: 'Sidro na ovoj stranici',
 	toEmail: 'E-Mail',
 	toUrl: 'URL',
+	toPhone: 'Phone', // MISSING
 	toolbar: 'Ubaci/promijeni vezu',
 	type: 'Vrsta veze',
 	unlink: 'Ukloni vezu',
