@@ -1,5 +1,5 @@
 ﻿/**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -12,7 +12,7 @@
 
 ( function() {
 	CKEDITOR.plugins.add( 'magicline', {
-		lang: 'af,ar,az,bg,ca,cs,cy,da,de,de-ch,el,en,en-au,en-gb,eo,es,es-mx,et,eu,fa,fi,fr,fr-ca,gl,he,hr,hu,id,it,ja,km,ko,ku,lv,nb,nl,no,oc,pl,pt,pt-br,ro,ru,si,sk,sl,sq,sv,tr,tt,ug,uk,vi,zh,zh-cn', // %REMOVE_LINE_CORE%
+		lang: 'af,ar,az,bg,ca,cs,cy,da,de,de-ch,el,en,en-au,en-gb,eo,es,es-mx,et,eu,fa,fi,fr,fr-ca,gl,he,hr,hu,id,it,ja,km,ko,ku,lt,lv,nb,nl,no,oc,pl,pt,pt-br,ro,ru,si,sk,sl,sq,sr,sr-latn,sv,tr,tt,ug,uk,vi,zh,zh-cn', // %REMOVE_LINE_CORE%
 		init: initPlugin
 	} );
 
@@ -340,7 +340,7 @@
 
 			// This one allows testing and debugging. It reveals some
 			// inner methods to the world.
-			this.backdoor = {
+			editor._.magiclineBackdoor = {
 				accessFocusSpace: accessFocusSpace,
 				boxTrigger: boxTrigger,
 				isLine: isLine,
@@ -1775,8 +1775,8 @@
  * causes the magic line to appear. This option accepts a value in pixels, without the unit (for example:
  * `15` for 15 pixels).
  *
- * Read more in the [documentation](#!/guide/dev_magicline)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/magicline.html).
+ * Read more in the {@glink features/magicline documentation}
+ * and see the {@glink examples/magicline example}.
  *
  *		// Changes the offset to 15px.
  *		CKEDITOR.config.magicline_triggerOffset = 15;
@@ -1791,8 +1791,8 @@
  * which the magic line stays revealed and no other focus space is offered to be accessed.
  * This value is relative to {@link #magicline_triggerOffset}.
  *
- * Read more in the [documentation](#!/guide/dev_magicline)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/magicline.html).
+ * Read more in the {@glink features/magicline documentation}
+ * and see the {@glink examples/magicline example}.
  *
  *		// Increases the distance to 80% of CKEDITOR.config.magicline_triggerOffset.
  *		CKEDITOR.config.magicline_holdDistance = .8;
@@ -1806,8 +1806,8 @@
  * Defines the default keystroke that accesses the closest unreachable focus space **before**
  * the caret (start of the selection). If there is no focus space available, the selection remains unchanged.
  *
- * Read more in the [documentation](#!/guide/dev_magicline)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/magicline.html).
+ * Read more in the {@glink features/magicline documentation}
+ * and see the {@glink examples/magicline example}.
  *
  *		// Changes the default keystroke to "Ctrl + ,".
  *		CKEDITOR.config.magicline_keystrokePrevious = CKEDITOR.CTRL + 188;
@@ -1821,8 +1821,8 @@ CKEDITOR.config.magicline_keystrokePrevious = CKEDITOR.CTRL + CKEDITOR.SHIFT + 5
  * Defines the default keystroke that accesses the closest unreachable focus space **after**
  * the caret (start of the selection). If there is no focus space available, the selection remains unchanged.
  *
- * Read more in the [documentation](#!/guide/dev_magicline)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/magicline.html).
+ * Read more in the {@glink features/magicline documentation}
+ * and see the {@glink examples/magicline example}.
  *
  *		// Changes keystroke to "Ctrl + .".
  *		CKEDITOR.config.magicline_keystrokeNext = CKEDITOR.CTRL + 190;
@@ -1836,8 +1836,8 @@ CKEDITOR.config.magicline_keystrokeNext = CKEDITOR.CTRL + CKEDITOR.SHIFT + 52; /
  * Defines a list of attributes that, if assigned to some elements, prevent the magic line from being
  * used within these elements.
  *
- * Read more in the [documentation](#!/guide/dev_magicline)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/magicline.html).
+ * Read more in the {@glink features/magicline documentation}
+ * and see the {@glink examples/magicline example}.
  *
  *		// Adds the "data-tabu" attribute to the magic line tabu list.
  *		CKEDITOR.config.magicline_tabuList = [ 'data-tabu' ];
@@ -1849,8 +1849,8 @@ CKEDITOR.config.magicline_keystrokeNext = CKEDITOR.CTRL + CKEDITOR.SHIFT + 52; /
 /**
  * Defines the color of the magic line. The color may be adjusted to enhance readability.
  *
- * Read more in the [documentation](#!/guide/dev_magicline)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/magicline.html).
+ * Read more in the {@glink features/magicline documentation}
+ * and see the {@glink examples/magicline example}.
  *
  *		// Changes magic line color to blue.
  *		CKEDITOR.config.magicline_color = '#0000FF';
@@ -1863,8 +1863,8 @@ CKEDITOR.config.magicline_keystrokeNext = CKEDITOR.CTRL + CKEDITOR.SHIFT + 52; /
  * Activates the special all-encompassing mode that considers all focus spaces between
  * {@link CKEDITOR.dtd#$block} elements as accessible by the magic line.
  *
- * Read more in the [documentation](#!/guide/dev_magicline)
- * and see the [SDK sample](https://sdk.ckeditor.com/samples/magicline.html).
+ * Read more in the {@glink features/magicline documentation}
+ * and see the {@glink examples/magicline example}.
  *
  *		// Enables the greedy "put everywhere" mode.
  *		CKEDITOR.config.magicline_everywhere = true;
