@@ -1,5 +1,5 @@
-﻿/**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/**
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -38,6 +38,7 @@ CKEDITOR.plugins.add( 'panelbutton', {
 			$: function( definition ) {
 				// We don't want the panel definition in this object.
 				var panelDefinition = definition.panel || {};
+
 				delete definition.panel;
 
 				this.base( definition );
@@ -49,7 +50,7 @@ CKEDITOR.plugins.add( 'panelbutton', {
 				};
 				panelDefinition.toolbarRelated = true;
 
-				this.hasArrow = true;
+				this.hasArrow = 'listbox';
 
 				this.click = clickFn;
 
@@ -70,19 +71,22 @@ CKEDITOR.plugins.add( 'panelbutton', {
 				createPanel: function( editor ) {
 					var _ = this._;
 
-					if ( _.panel )
+					if ( _.panel ) {
 						return;
+					}
 
 					var panelDefinition = this._.panelDefinition,
 						panelBlockDefinition = this._.panelDefinition.block,
 						panelParentElement = panelDefinition.parent || CKEDITOR.document.getBody(),
 						panel = this._.panel = new CKEDITOR.ui.floatPanel( editor, panelParentElement, panelDefinition ),
 						block = panel.addBlock( _.id, panelBlockDefinition ),
-						me = this;
+						me = this,
+						command = editor.getCommand( this.command );
 
 					panel.onShow = function() {
-						if ( me.className )
+						if ( me.className ) {
 							this.element.addClass( me.className + '_panel' );
+						}
 
 						me.setState( CKEDITOR.TRISTATE_ON );
 
@@ -90,20 +94,28 @@ CKEDITOR.plugins.add( 'panelbutton', {
 
 						me.editorFocus && editor.focus();
 
-						if ( me.onOpen )
+						if ( me.onOpen ) {
 							me.onOpen();
+						}
 					};
 
 					panel.onHide = function( preventOnClose ) {
-						if ( me.className )
+						if ( me.className ) {
 							this.element.getFirst().removeClass( me.className + '_panel' );
+						}
 
-						me.setState( me.modes && me.modes[ editor.mode ] ? CKEDITOR.TRISTATE_OFF : CKEDITOR.TRISTATE_DISABLED );
+						// Defined `modes` has priority over the command for a backward compatibility (#3727).
+						if ( !me.modes && command ) {
+							me.setStateFromCommand( command );
+						} else {
+							me.setState( me.modes && me.modes[ editor.mode ] ? CKEDITOR.TRISTATE_OFF : CKEDITOR.TRISTATE_DISABLED );
+						}
 
 						_.on = 0;
 
-						if ( !preventOnClose && me.onClose )
+						if ( !preventOnClose && me.onClose ) {
 							me.onClose();
+						}
 					};
 
 					panel.onEscape = function() {
@@ -111,13 +123,24 @@ CKEDITOR.plugins.add( 'panelbutton', {
 						me.document.getById( _.id ).focus();
 					};
 
-					if ( this.onBlock )
+					if ( this.onBlock ) {
 						this.onBlock( panel, block );
+					}
 
 					block.onHide = function() {
 						_.on = 0;
-						me.setState( CKEDITOR.TRISTATE_OFF );
+
+						// Defined `modes` has priority over the command for a backward compatibility (#3727).
+						if ( !me.modes && me.command ) {
+							me.setStateFromCommand( command );
+						} else {
+							me.setState( CKEDITOR.TRISTATE_OFF );
+						}
 					};
+				},
+
+				setStateFromCommand: function( command ) {
+					this.setState( command.state );
 				}
 			}
 		} );
