@@ -1,11 +1,11 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'stylescombo', 'sk', {
 	label: 'Štýly',
 	panelTitle: 'Formátovanie štýlov',
 	panelTitle1: 'Štýly bloku',
-	panelTitle2: 'Vnútroriadkové (inline) štýly',
-	panelTitle3: 'Štýly objeku'
+	panelTitle2: 'Znakové štýly',
+	panelTitle3: 'Štýly objektu'
 } );
