@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'table', 'et', {
@@ -50,6 +50,7 @@ CKEDITOR.plugins.setLang( 'table', 'et', {
 	headersColumn: 'Esimene tulp',
 	headersNone: 'Puudub',
 	headersRow: 'Esimene rida',
+	heightUnit: 'kõrgusühik',
 	invalidBorder: 'Äärise suurus peab olema number.',
 	invalidCellPadding: 'Lahtrite polsterdus (padding) peab olema positiivne arv.',
 	invalidCellSpacing: 'Lahtrite vahe peab olema positiivne arv.',
