@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'table', 'hu', {
@@ -50,6 +50,7 @@ CKEDITOR.plugins.setLang( 'table', 'hu', {
 	headersColumn: 'Első oszlop',
 	headersNone: 'Nincsenek',
 	headersRow: 'Első sor',
+	heightUnit: 'Magasság egység',
 	invalidBorder: 'A szegélyméret mezőbe csak számokat írhat.',
 	invalidCellPadding: 'A cella belső margó mezőbe csak számokat írhat.',
 	invalidCellSpacing: 'A cella térköz mezőbe csak számokat írhat.',
