@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'table', 'zh', {
@@ -17,8 +17,8 @@ CKEDITOR.plugins.setLang( 'table', 'zh', {
 		splitVertical: '垂直分割儲存格',
 		title: '儲存格屬性',
 		cellType: '儲存格類型',
-		rowSpan: '列全長',
-		colSpan: '行全長',
+		rowSpan: '行全長',
+		colSpan: '列全長',
 		wordWrap: '自動斷行',
 		hAlign: '水平對齊',
 		vAlign: '垂直對齊',
@@ -31,40 +31,41 @@ CKEDITOR.plugins.setLang( 'table', 'zh', {
 		no: '否',
 		invalidWidth: '儲存格寬度必須為數字。',
 		invalidHeight: '儲存格高度必須為數字。',
-		invalidRowSpan: '列全長必須是整數。',
-		invalidColSpan: '行全長必須是整數。',
+		invalidRowSpan: '行全長必須是整數。',
+		invalidColSpan: '列全長必須是整數。',
 		chooseColor: '選擇'
 	},
 	cellPad: '儲存格邊距',
 	cellSpace: '儲存格間距',
 	column: {
-		menu: '行',
-		insertBefore: '左方插入行',
-		insertAfter: '右方插入行',
-		deleteColumn: '刪除行'
+		menu: '列',
+		insertBefore: '左方插入列',
+		insertAfter: '右方插入列',
+		deleteColumn: '刪除列'
 	},
-	columns: '行',
+	columns: '列',
 	deleteTable: '刪除表格',
 	headers: '頁首',
 	headersBoth: '同時',
-	headersColumn: '第一行',
+	headersColumn: '第一列',
 	headersNone: '無',
-	headersRow: '第一列',
+	headersRow: '第一行',
+	heightUnit: 'height unit', // MISSING
 	invalidBorder: '框線大小必須是整數。',
 	invalidCellPadding: '儲存格邊距必須為正數。',
 	invalidCellSpacing: '儲存格間距必須為正數。',
-	invalidCols: '行數須為大於 0 的正整數。',
+	invalidCols: '列數須為大於 0 的正整數。',
 	invalidHeight: '表格高度必須為數字。',
-	invalidRows: '列數須為大於 0 的正整數。',
+	invalidRows: '行數須為大於 0 的正整數。',
 	invalidWidth: '表格寬度必須為數字。',
 	menu: '表格屬性',
 	row: {
-		menu: '列',
-		insertBefore: '上方插入列',
-		insertAfter: '下方插入列',
-		deleteRow: '刪除列'
+		menu: '行',
+		insertBefore: '上方插入行',
+		insertAfter: '下方插入行',
+		deleteRow: '刪除行'
 	},
-	rows: '列',
+	rows: '行',
 	summary: '總結',
 	title: '表格屬性',
 	toolbar: '表格',
