@@ -1,8 +1,8 @@
-﻿/**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/**
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 CKEDITOR.plugins.setLang( 'widget', 'fa', {
 	'move': 'کلیک و کشیدن برای جابجایی',
-	'label': '%1 widget' // MISSING
+	'label': 'ابزارک %1'
 } );
